import MySQLdb

account = {"host": "localhost", "username": "root", "password": ""}


def modify(host_t, username_t, password_t):
    global account
    account["host"] = host_t
    account["username"] = username_t
    account["password"] = password_t
    return account


def create(account):
    db = MySQLdb.connect(
        account["host"], account["username"], account["password"], "sys", charset="utf8"
    )
    cursor = db.cursor()
    cursor.execute("CREATE DATABASE if Not Exists pianyuan;")
    cursor.execute("USE pianyuan;")
    cursor.execute(
        "create table if Not Exists film(quality char(50),moive_name mediumblob, url mediumblob,size char(50),flash_time char(50))ENGINE=MyISAM DEFAULT CHARSET=utf8;"
    )
    db.commit()
    return db


def close(db):
    db.close()


def delect(db, table):
    cursor = db.cursor()
    cursor.execute("USE pianyuan;")
    if table == "film":
        cursor.execute("truncate table film;")
    db.commit()


def add(info, db):
    cursor = db.cursor()
    sql = "insert into film(quality,moive_name,url,size,flash_time) values(%s,%s,%s,%s,%s)"
    cursor.execute(
        sql,
        (
            str(info["quality"]),
            str(info["movie_name"]),
            str(info["url"]),
            str(info["size"]),
            str(info["flash_time"]),
        ),
    )
    db.commit()


def number(db):
    cur = db.cursor()
    print("共有%d条记录" % cur.execute("SELECT * FROM pianyuan.film;"))



from bs4 import BeautifulSoup
import requests
import bs4
from pianyuan import mysql
import time

mainWeb = "http://www.pianyuan.la"
mv_web = "http://pianyuan.la/mv?order=score"

acc = mysql.account

# get film page from main page's recommend
# page : page number of main recommend list
# number : the film position in page


# Question A: how can we get the recommend movies' name and match with its href?
def get_recommend(page, number):
    if page == 1:
        web = mainWeb
    else:
        web = mainWeb + "/" + "?p=" + str(page)
    response = requests.get(web)
    # else: page >100
    # 相应的保护措施（或者前端做限制）
    soup = BeautifulSoup(response.text, "html.parser")
    film = soup.find_all(
        name="a", attrs={"class": "ico ico_bt"}
    )  # lass located to find the target
    for i in film:
        i["href"] = mainWeb + i["href"]
    return film[number]["href"]


# SUGGESTION:
# This is a film_download_link, not the download function.
# Can we change this function's name?
def get_film_download(url):
    res = {"url": "null", "bt": "null", "subtitle": "null"}
    response = requests.get(url)
    soup = BeautifulSoup(response.text, "html.parser")
    film = soup.find_all(name="a", attrs={"class": "btn btn-danger btn-sm"})
    res["url"] = mainWeb + film[0]["href"]
    film = soup.find_all(name="a", attrs={"class": "btn btn-primary btn-sm"})
    res["bt"] = film[0]["href"]
    film = soup.find_all(name="a", attrs={"class": "btn btn-success btn-sm"})
    res["subtitle"] = film[0]["href"]
    return res


def get_link(url):
    res = {"douban": "null", "more": "null"}
    response = requests.get(url)
    soup = BeautifulSoup(response.text, "html.parser")
    douban = soup.find_all(name="a", attrs={"title": "豆瓣链接"})
    more = soup.find_all(name="a", attrs={"class": "text-danger"})
    res["douban"] = "https:" + douban[0]["href"]
    res["more"] = "http://pianyuan.la" + more[0]["href"]
    return res


def get_res_type(url):
    response = requests.get(url)
    soup = BeautifulSoup(response.text, "html.parser")
    douban = soup.find_all(name="span", attrs={"class": "label label-warning"})
    print(douban[0].string)


def get_inf(url):
    inf = {"name": "null", "number": "null", "douban": "null"}
    response = requests.get(url)
    soup = BeautifulSoup(response.text, "html.parser")
    douban = soup.find_all(name="a", attrs={"title": "豆瓣链接", "target": "_blank"})
    douban = "https:" + douban[0]["href"]
    inf["douban"] = douban
    print(soup.html.body.h1.string)


def get_more_film(url):
    page = []
    response = requests.get(url)
    soup = BeautifulSoup(response.text, "html.parser")
    items = soup.find_all(name="table", attrs={"class": "data"})  # 所有的资源列表，每一个代表一个清晰度
    for i in items:  # 取其中一个清晰度
        quatify = i.find(name="span", attrs={"class": "label label-warning"}).text
        films = i.find_all(name="tr", attrs={"class": "odd"})
        films += i.find_all(name="tr", attrs={"class": "even"})  # 取得所有子资源
        for j in films:  # 抽取其中一个子资源
            info = {}
            htxt = j.find(name="td", attrs={"class": "nobr"})  # 找到它带名字的超文本
            url = htxt.find(name="a", attrs={"class": "ico ico_bt"})  # 取得更细节的超文本信息
            if isinstance(url, bs4.element.Tag) is False:
                url = htxt.find(name="a", attrs={"class": "ico ico_ed2k"})
                if isinstance(url, bs4.element.Tag) is False:
                    url = htxt.find(name="a", attrs={"class": "ico"})  # 取得更细节的超文本信息
            name = url.string  # 取得名字
            url = "http://pianyuan.la" + url["href"]  # 取得链接 btn  btn-primary btn-sm
            size = j.find(name="td", attrs={"class": "nobr center"}).string  # 取得大小信息
            time = j.find(
                name="td", attrs={"class": "nobr lasttd center"}
            ).string  # 取得更新时间信息
            info["quality"] = quatify  # 收录此子资信息到字典
            info["movie_name"] = name
            info["url"] = url
            info["size"] = size
            info["flash_time"] = time
            page.append(info)
    return page  # 取得一个页面，也就是一部电影的所有资源


def next_page(page):
    return "http://pianyuan.la/mv?order=score&p=" + str(page)


def get_list(url, page, db):
    film_list_number = 0
    response = requests.get(url)
    soup = BeautifulSoup(response.text, "html.parser")
    items = soup.find_all(
        name="div", attrs={"class": "col-sm-3 col-md-3 col-xs-4 col-lg-2 nopl"}
    )  # 取得一个页面的所有电影
    start = time.time()
    for x in range(0, 118, 3):  # 存一部电影的所有资源信息到数据库
        i = items[film_list_number]  # 取其中一部电影
        film = i.find(name="a")
        film["href"] = "http://pianyuan.la" + film["href"]  # 取得一部电影的链接
        all_res = get_more_film(film["href"])  # 取得一部电影的所有资源到all_res里
        for r in all_res:  # 取得某一个资源
            mysql.add(r, db)
        num = x // 2
        if x == 107:
            process = "\r[%3d#NO.%3d]: |%-51s|本次运行时间:%3ds\n" % (
                page,
                x / 3 + 1,
                "|" * (num - 1),
                (time.time() - start),
            )
        else:
            process = "\r[%3d#NO.%3d]: |%-51s|本次运行时间:%3ds" % (
                page,
                x / 3 + 1,
                "|" * (num - 1),
                (time.time() - start),
            )
        print(process, end="", flush=True)
        if film_list_number == 35:
            return 0
        else:
            film_list_number = film_list_number + 1


def run(s, f, db):
    page = int(s)
    while page <= int(f):
        get_list(next_page(page), page, db)
        page = page + 1



import argparse
from pianyuan.spider import *
from pianyuan.shell import *
from pianyuan.package import *


def main():
    start =0
    end =0
    host = ""
    usename = ""
    password = ""
    parser = argparse.ArgumentParser()
    parser.add_argument("-G", help="login in mysql and Crawl", type=str, nargs=5)
    parser.add_argument("-g", help="login in mysql without password and Crawl", type=str, nargs=4)
    parser.add_argument("-S", help="Shell action", type=str, nargs=1)
    parser.add_argument("-P", help="package action", type=str, nargs=1)
    args = parser.parse_args()
    if args.G or args.g:
        if args.G:
            start = args.G[0]
            end = args.G[0]
            host = args.G[2]
            usename = args.G[3]
            password = args.G[4]
        elif args.g:
            start = args.g[0]
            end = args.g[0]
            host = args.g[2]
            usename = args.g[3]
        acc = mysql.modify(host, usename, password)
        db = mysql.create(acc)
        run(start, end)
    if args.S:
        if args.S[0] == "init":
            init()
        elif args.S[0] == "beautify":
            beautify()
        elif args.S[0] == "test":
            test()
        else:
            print("There is no action : " + args.S[0])
    if args.P:
        if args.P[0]=="package":
            package()
        elif args.P[0]=="upload":
            upload()
        else:
            print("There is no action : " + args.S[0])
if __name__ == "__main__":
    main()



import sys,os,json

def getVersion():
    NowPath = os.getcwd()
    with open(NowPath+"\\"+"\\pianyuan\\__init__.py","r") as f:
        tmp = f.read()
        tmp =json.loads(tmp)
        tmp = tmp["inf"][0]['version']
    return tmp



from pianyuan import getInf
import os,sys
version = getInf.getVersion()
upload_path = "twine upload " + os.getcwd()+"\\dist\\pianyuan-" + version + ".tar.gz"
def package():
    print("start packaging =================================")
    os.system(r"python setup.py sdist")

def upload():
    package()
    print("start upload=====================================")
    os.system(upload_path)
    os.system(r"pip install --upgrade pianyuan --user")




from bs4 import BeautifulSoup

# import requests
# import bs4
# import re


def get_douban_inf():
    # direct:导演  starring:演员  genre：
    # inf = {'direct':'null','starring':'null','genre':'null','loca':'null','lang':'null','time':'null'}
    # response = requests.get(url)
    htmlfile = open(
        "C:/Users/97607/Documents/GitHub/Python/PianYuan/html/mainWeb.html",
        "r",
        encoding="utf8",
    )
    htmlpage = htmlfile.read()

    soup = BeautifulSoup(htmlpage, "html.parser")
    # mov_info = soup(id="info")[0]

    # for循环里面的东西不能重复

    # 评论

    comment_info = soup.find_all(class_="comment")
    for child in comment_info:
        com_name_te = child.find_all(name="a", class_="")
        for childc1 in com_name_te:
            if childc1.string == "展开":
                print()
            else:
                print(childc1.string)

        com_say = child.find_all(name="span", class_="short")
        com_say_re = child.find_all(name="span", class_="hide-item full")
        for childc2 in com_say_re:
            if childc2.string == "":
                for childc3 in com_say:
                    print(childc3.string)
            else:
                print(childc2.string)

    # 简介
    """
    comment_info = soup.find_all(class_="comment")
    for child in comment_info:
        com_name_te = child.find_all(name='a',class_="")
        for child1 in com_name_te:
            print(child1.string)

        com = child.find_all(class_="short")
        if(child.find_all(class_="short"))


        for child2 in com:
            print(child2.string)

        print("")

    """


"""

    #获取电影简介（以string形式输出）
    intro_te = soup(name='span',attrs={"property":"v:summary"})
    for child in intro_te:
        print(child.string)

    #获取主演名称
    star_te = soup(rel="v:starring")
    for child in star_te:
        print(child.string)

    #获取类型名称
    cate_te = soup(property="v:genre")
    for child in cate_te:
        print(child.string)

    #获取上映日期
    date_te = soup(property="v:initialReleaseDate")
    for child in date_te:
        print(child.string)



    #获取其他相关信息
    compil_dire = r'导演<.*?><.*>(.+)</a>'
    compil_writ = r'编剧<.*?><.*>(.+)</a>'
    compil_loca = r'制片国家/地区:<.*?> (.+)<.*>'
    compil_lang = r'语言:<.*?> (.+)<.*>'
    compil_runt = r'片长:<.*?>.*<.*?>(.+)</.*>'
    compil_otna = r'又名:<.*?> (.+)<.*>'


    dire = re.findall(compil_dire,str(mov_info))
    writ = re.findall(compil_writ,str(mov_info))
    loca = re.findall(compil_loca,str(mov_info))
    lang = re.findall(compil_lang,str(mov_info))
    runt = re.findall(compil_runt,str(mov_info))
    otna = re.findall(compil_otna,str(mov_info))


    print(dire)
    print(writ)
    print(loca)
    print(lang)
    print(date)
    print(runt)
    print(otna)

"""


# 主程序入口，最后封装请直接删除
if __name__ == "__main__":
    get_douban_inf()



import setuptools
from pianyuan import *
from pianyuan import getInf
with open("README.md", "r", encoding="UTF-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pianyuan",
    version=getInf.getVersion(),
    author="WangTingZheng",
    author_email="wangtingzheng@outlook.com",
    description="a spider from pianyuan.la",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ptrtonull-workshop/pianyuan",
    packages=setuptools.find_packages(),
    entry_points = {
        'console_scripts': [
            'pianyuan = pianyuan.main:main',
        ]
    }
)



import os


def init():
    os.system("pip3 install -r requirements.txt")


def test():
    if os.system("flake8  --ignore E501 F403 F405 F401") != 0:
        exit("test error")


def beautify():
    os.system("black ./pianyuan")
